@@ -15,7 +15,7 @@ class BaseMetadata(BaseModel):
         exclude_unset: bool = False,
         exclude_defaults: bool = False,
         exclude_none: bool = True,
-        to_rdf: bool = False
+        to_rdf: bool = False,
     ) -> 'DictStrAny':
         """
         Generate a dictionary representation of the model, optionally specifying which fields to include or exclude.
@@ -98,7 +98,7 @@ class BaseMetadata(BaseModel):
                             "title": "Key-Value",
                             "description": "A key-value pair",
                             "properties": {"key": {"type": "string"}, "value": {"type": "string"}},
-                            "required": ["key", "value"],
+                            # "required": ["key", "value"],  TODO re-enable when form generation implements this correctly
                         }
 
 
