@@ -1,4 +1,4 @@
-from hsmodels.schemas.enums import CoverageType, DateType, RelationType, UserIdentifierType
+from hsmodels.schemas.enums import CoverageType, DateType, ModelProgramFileType, RelationType, UserIdentifierType
 from hsmodels.utils import to_coverage_dict
 
 
@@ -87,3 +87,35 @@ def group_user_identifiers(cls, values):
                 identifiers[identifier] = values[identifier.name]
         values["identifiers"] = identifiers
     return values
+
+
+def parse_file_types(cls, values):
+    file_types_list = []
+    for file_type in ModelProgramFileType:
+        if file_type.name in values:
+            ftypes = values[file_type.name]
+            if isinstance(ftypes, list):
+                for ftype in ftypes:
+                    file_types_list.append({"type": file_type, "url": ftype})
+                del values[file_type.name]
+    values['file_types'] = file_types_list
+    return values
+
+
+def normalize_additional_metadata(cls, values):
+    if "additional_metadata" in values:
+        value = values["additional_metadata"]
+        if isinstance(value, list):
+            as_dict = {}
+            for val in value:
+                if not isinstance(val, dict):
+                    raise ValueError(f"List entry {val} must be a dict")
+                if "key" not in val:
+                    raise ValueError(f"Missing the 'key' key in {val}")
+                if "value" not in val:
+                    raise ValueError(f"Missing the 'value' key in {val}")
+                if val["key"] in as_dict:
+                    raise ValueError(f"Found a duplicate key {val['key']}")
+                as_dict[val["key"]] = val["value"]
+            values["additional_metadata"] = as_dict
+    return values
